// <copyright file="CustomQueryAuthenticationManager.cs" company="APIMatic">
// Copyright (c) APIMatic. All rights reserved.
// </copyright>
namespace ShippingAPI.Standard.Authentication
{
    using System.Collections.Generic;
    using System.Threading.Tasks;
    using ShippingAPI.Standard.Http.Request;

    /// <summary>
    /// CustomQueryAuthenticationManager.
    /// </summary>
    internal class CustomQueryAuthenticationManager : ICustomQueryAuthenticationCredentials, IAuthManager
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="CustomQueryAuthenticationManager"/> class.
        /// </summary>
        /// <param name="apikey">apikey.</param>
        public CustomQueryAuthenticationManager(string apikey)
        {
            this.Apikey = apikey;
        }

        /// <summary>
        /// Gets apikey.
        /// </summary>
        public string Apikey { get; }

        /// <summary>
        /// Check if credentials match.
        /// </summary>
        /// <param name="apikey"> apikey.</param>
        /// <returns> The boolean value.</returns>
        public bool Equals(string apikey)
        {
            return apikey.Equals(this.Apikey);
        }

        /// <inheritdoc/>
        public HttpRequest Apply(HttpRequest httpRequest)
        {
            httpRequest.AddQueryParameters(new Dictionary<string, object>
            {
                { "apikey", this.Apikey },
            });

            return httpRequest;
        }

        /// <inheritdoc/>
        public Task<HttpRequest> ApplyAsync(HttpRequest httpRequest)
        {
            return Task.FromResult(this.Apply(httpRequest));
        }
    }
}
