
# Client Class Documentation

The following parameters are configurable for the API Client:

| Parameter | Type | Description |
|  --- | --- | --- |
| `ContentType` | `string` | *Default*: `"application/x-www-form-urlencoded"` |
| `InstanceURL` | `string` | Replace yourinstance.transtream.com with the URL of your instance. You will also need to change the API Key for the call be successful<br>*Default*: `"yourinstance.transtream.com"` |
| `Environment` | Environment | The API environment. <br> **Default: `Environment.Production`** |
| `Timeout` | `TimeSpan` | Http client timeout.<br>*Default*: `TimeSpan.FromSeconds(100)` |
| `Apikey` | `string` | *Default*: `"<Obtain API Key>"` |

The API client can be initialized as follows:

```csharp
ShippingAPI.Standard.ShippingAPIClient client = new ShippingAPI.Standard.ShippingAPIClient.Builder()
    .CustomQueryAuthenticationCredentials("<Obtain API Key>")
    .ContentType(GetEnvironmentVariable("application/x-www-form-urlencoded"))
    .Environment(ShippingAPI.Standard.Environment.Production)
    .InstanceURL("yourinstance.transtream.com")
    .HttpClientConfig(config => config.NumberOfRetries(0))
    .Build();
```

## Shipping APIClient Class

The gateway for the SDK. This class acts as a factory for the Controllers and also holds the configuration of the SDK.

### Controllers

| Name | Description |
|  --- | --- |
| CommonController | Gets CommonController controller. |

### Properties

| Name | Description | Type |
|  --- | --- | --- |
| HttpClientConfiguration | Gets the configuration of the Http Client associated with this client. | `IHttpClientConfiguration` |
| Timeout | Http client timeout. | `TimeSpan` |
| ContentType | - | `string` |
| Environment | Current API environment. | `Environment` |
| InstanceURL | Replace yourinstance.transtream.com with the URL of your instance. You will also need to change the API Key for the call be successful | `string` |

### Methods

| Name | Description | Return Type |
|  --- | --- | --- |
| `GetBaseUri(Server alias = Server.YourInstance)` | Gets the URL for a particular alias in the current environment and appends it with template parameters. | `string` |
| `ToBuilder()` | Creates an object of the Shipping APIClient using the values provided for the builder. | `Builder` |

## Shipping APIClient Builder Class

Class to build instances of Shipping APIClient.

### Methods

| Name | Description | Return Type |
|  --- | --- | --- |
| `HttpClientConfiguration(Action<HttpClientConfiguration.Builder> action)` | Gets the configuration of the Http Client associated with this client. | `Builder` |
| `Timeout(TimeSpan timeout)` | Http client timeout. | `Builder` |
| `ContentType(string contentType)` | - | `Builder` |
| `Environment(Environment environment)` | Current API environment. | `Builder` |
| `InstanceURL(string instanceURL)` | Replace yourinstance.transtream.com with the URL of your instance. You will also need to change the API Key for the call be successful | `Builder` |

